
#define cimg_display 0 //Disable GUI parts of CImg library


#include "CImg/CImg.h"
#include "Dijkstra.h"
#include <iostream>

using namespace cimg_library;
using namespace std;



int main(int argc, char *argv[]){
  if(argc<3){
    cout<<"Example usage: Dijkstra image.bmp seeds.bmp"<<endl;
    return 0;
  }
  
  //Load image from file
  CImg<uint8> image(argv[1]);

  //load seed image
  CImg<uint8> seeds(argv[2]);

  //Run Dijkstras algorithm to compute, for every pixel, 
  //the distance to the closest non-zero pixel in "seeds"
  //in an edge weighted graph defined over the image
  // (You need to implement this function in "Dijkstra.cpp"!)
  CImg<double> distances = Dijkstra(image, seeds);
  
  
  //Find maximum and minimum distance values.
  double min_value=distances.min();
  double max_value=distances.max();

  
  CImg<uint8> output(distances.width(), distances.height());

  //Rescale the distance map to the range 0-255 before saving to file
  for(long x=0; x<image.width(); x++){
    for(long y=0; y<image.height(); y++){
      double normalized_value=(distances(x,y)-min_value)/(max_value-min_value);
      output(x,y)=uint8(255*normalized_value);
    }
  }

  //Writing distance map to file
  output.save_bmp("result.bmp");

}
